# coding: utf-8

"""
    WordLift Fact-Checking API

    API for semi-automated fact-checking. Returns schema.org/ClaimReview markup. This markup is structured data that contains information about the fact check -- for example, what was the claim being assessed, who made the claim, what was the verdict.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from wordlift_client.models.filter import Filter
from typing import Optional, Set
from typing_extensions import Self

class VectorSearchQueryRequest(BaseModel):
    """
    A query request.
    """ # noqa: E501
    fields: Optional[List[StrictStr]] = Field(default=None, description="List of extra fields to be retrieved.")
    filters: Optional[List[Filter]] = Field(default=None, description="A list of prefilters.")
    query_embedding: Optional[List[Union[StrictFloat, StrictInt]]] = Field(default=None, description="The list of embeddings, not required if `query_string` is provided.")
    query_string: Optional[StrictStr] = Field(default=None, description="The query string, not required if the `query_embeddings` are provided. Please note that the `query_string` is ignored if the `query_embeddings` are provided.")
    query_uri: Optional[StrictStr] = Field(default=None, description="Perform a Vector Search based on similarities with an entity with the specified URI.")
    query_url: Optional[StrictStr] = Field(default=None, description="Perform a Vector Search based on similarities with an entity with the specified URL (schema:url).")
    similarity_top_k: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=2, description="The similarity top K.")
    __properties: ClassVar[List[str]] = ["fields", "filters", "query_embedding", "query_string", "query_uri", "query_url", "similarity_top_k"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VectorSearchQueryRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in filters (list)
        _items = []
        if self.filters:
            for _item in self.filters:
                if _item:
                    _items.append(_item.to_dict())
            _dict['filters'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VectorSearchQueryRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "fields": obj.get("fields"),
            "filters": [Filter.from_dict(_item) for _item in obj["filters"]] if obj.get("filters") is not None else None,
            "query_embedding": obj.get("query_embedding"),
            "query_string": obj.get("query_string"),
            "query_uri": obj.get("query_uri"),
            "query_url": obj.get("query_url"),
            "similarity_top_k": obj.get("similarity_top_k") if obj.get("similarity_top_k") is not None else 2
        })
        return _obj





# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.o_auth2_authorized_client_request import OAuth2AuthorizedClientRequest

class TestOAuth2AuthorizedClientRequest(unittest.TestCase):
    """OAuth2AuthorizedClientRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OAuth2AuthorizedClientRequest:
        """Test OAuth2AuthorizedClientRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OAuth2AuthorizedClientRequest`
        """
        model = OAuth2AuthorizedClientRequest()
        if include_optional:
            return OAuth2AuthorizedClientRequest(
                access_token_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                access_token_issued_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                access_token_scopes = '',
                access_token_type = '',
                access_token_value = '',
                client_registration_id = '',
                principal_name = '',
                refresh_token_issued_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                refresh_token_value = ''
            )
        else:
            return OAuth2AuthorizedClientRequest(
        )
        """

    def testOAuth2AuthorizedClientRequest(self):
        """Test OAuth2AuthorizedClientRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.response1 import Response1

class TestResponse1(unittest.TestCase):
    """Response1 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Response1:
        """Test Response1
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Response1`
        """
        model = Response1()
        if include_optional:
            return Response1(
                items = [
                    wordlift_client.models.event.Event(
                        source = '', 
                        args = wordlift_client.models.args.args(), 
                        url = '', 
                        recorded_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        account_id = 56, )
                    ],
                var_self = '',
                next = '',
                prev = '',
                last = '',
                first = ''
            )
        else:
            return Response1(
        )
        """

    def testResponse1(self):
        """Test Response1"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    WordLift Fact-Checking API

    API for semi-automated fact-checking. Returns schema.org/ClaimReview markup. This markup is structured data that contains information about the fact check -- for example, what was the claim being assessed, who made the claim, what was the verdict.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import List, Optional
from typing_extensions import Annotated
from wordlift_client.models.page_website import PageWebsite
from wordlift_client.models.page_website_search import PageWebsiteSearch

from wordlift_client.api_client import ApiClient, RequestSerialized
from wordlift_client.api_response import ApiResponse
from wordlift_client.rest import RESTResponseType


class GoogleSearchConsoleApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    async def list_website_search(
        self,
        website: Annotated[StrictStr, Field(description="The website URL")],
        since: Annotated[StrictStr, Field(description="The start date, inclusive, in yyyy-MM-dd format.")],
        until: Annotated[StrictStr, Field(description="The end date, inclusive, in yyyy-MM-dd format.")],
        dimensions: Annotated[List[StrictStr], Field(description="The dimensions, e.g. `query`, `page`. Must repeat for each dimension.")],
        google_access_token: Annotated[StrictStr, Field(description="The Google access token, must have access to the Google Search Console scope")],
        cursor: Annotated[Optional[StrictStr], Field(description="The cursor")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of results")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PageWebsiteSearch:
        """List Website Search data

        List the Website Search performance data

        :param website: The website URL (required)
        :type website: str
        :param since: The start date, inclusive, in yyyy-MM-dd format. (required)
        :type since: str
        :param until: The end date, inclusive, in yyyy-MM-dd format. (required)
        :type until: str
        :param dimensions: The dimensions, e.g. `query`, `page`. Must repeat for each dimension. (required)
        :type dimensions: List[str]
        :param google_access_token: The Google access token, must have access to the Google Search Console scope (required)
        :type google_access_token: str
        :param cursor: The cursor
        :type cursor: str
        :param limit: The maximum number of results
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_website_search_serialize(
            website=website,
            since=since,
            until=until,
            dimensions=dimensions,
            google_access_token=google_access_token,
            cursor=cursor,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PageWebsiteSearch",
            '401': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def list_website_search_with_http_info(
        self,
        website: Annotated[StrictStr, Field(description="The website URL")],
        since: Annotated[StrictStr, Field(description="The start date, inclusive, in yyyy-MM-dd format.")],
        until: Annotated[StrictStr, Field(description="The end date, inclusive, in yyyy-MM-dd format.")],
        dimensions: Annotated[List[StrictStr], Field(description="The dimensions, e.g. `query`, `page`. Must repeat for each dimension.")],
        google_access_token: Annotated[StrictStr, Field(description="The Google access token, must have access to the Google Search Console scope")],
        cursor: Annotated[Optional[StrictStr], Field(description="The cursor")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of results")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PageWebsiteSearch]:
        """List Website Search data

        List the Website Search performance data

        :param website: The website URL (required)
        :type website: str
        :param since: The start date, inclusive, in yyyy-MM-dd format. (required)
        :type since: str
        :param until: The end date, inclusive, in yyyy-MM-dd format. (required)
        :type until: str
        :param dimensions: The dimensions, e.g. `query`, `page`. Must repeat for each dimension. (required)
        :type dimensions: List[str]
        :param google_access_token: The Google access token, must have access to the Google Search Console scope (required)
        :type google_access_token: str
        :param cursor: The cursor
        :type cursor: str
        :param limit: The maximum number of results
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_website_search_serialize(
            website=website,
            since=since,
            until=until,
            dimensions=dimensions,
            google_access_token=google_access_token,
            cursor=cursor,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PageWebsiteSearch",
            '401': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def list_website_search_without_preload_content(
        self,
        website: Annotated[StrictStr, Field(description="The website URL")],
        since: Annotated[StrictStr, Field(description="The start date, inclusive, in yyyy-MM-dd format.")],
        until: Annotated[StrictStr, Field(description="The end date, inclusive, in yyyy-MM-dd format.")],
        dimensions: Annotated[List[StrictStr], Field(description="The dimensions, e.g. `query`, `page`. Must repeat for each dimension.")],
        google_access_token: Annotated[StrictStr, Field(description="The Google access token, must have access to the Google Search Console scope")],
        cursor: Annotated[Optional[StrictStr], Field(description="The cursor")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of results")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Website Search data

        List the Website Search performance data

        :param website: The website URL (required)
        :type website: str
        :param since: The start date, inclusive, in yyyy-MM-dd format. (required)
        :type since: str
        :param until: The end date, inclusive, in yyyy-MM-dd format. (required)
        :type until: str
        :param dimensions: The dimensions, e.g. `query`, `page`. Must repeat for each dimension. (required)
        :type dimensions: List[str]
        :param google_access_token: The Google access token, must have access to the Google Search Console scope (required)
        :type google_access_token: str
        :param cursor: The cursor
        :type cursor: str
        :param limit: The maximum number of results
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_website_search_serialize(
            website=website,
            since=since,
            until=until,
            dimensions=dimensions,
            google_access_token=google_access_token,
            cursor=cursor,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PageWebsiteSearch",
            '401': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_website_search_serialize(
        self,
        website,
        since,
        until,
        dimensions,
        google_access_token,
        cursor,
        limit,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'dimensions': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if website is not None:
            
            _query_params.append(('website', website))
            
        if cursor is not None:
            
            _query_params.append(('cursor', cursor))
            
        if since is not None:
            
            _query_params.append(('since', since))
            
        if until is not None:
            
            _query_params.append(('until', until))
            
        if dimensions is not None:
            
            _query_params.append(('dimensions', dimensions))
            
        if google_access_token is not None:
            
            _query_params.append(('google_access_token', google_access_token))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/ext/google/searchconsole/searches',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def list_websites(
        self,
        google_access_token: Annotated[StrictStr, Field(description="The Google access token, must have access to the Google Search Console scope")],
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of results")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PageWebsite:
        """List

        List the Websites

        :param google_access_token: The Google access token, must have access to the Google Search Console scope (required)
        :type google_access_token: str
        :param limit: The maximum number of results
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_websites_serialize(
            google_access_token=google_access_token,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PageWebsite",
            '401': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def list_websites_with_http_info(
        self,
        google_access_token: Annotated[StrictStr, Field(description="The Google access token, must have access to the Google Search Console scope")],
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of results")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PageWebsite]:
        """List

        List the Websites

        :param google_access_token: The Google access token, must have access to the Google Search Console scope (required)
        :type google_access_token: str
        :param limit: The maximum number of results
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_websites_serialize(
            google_access_token=google_access_token,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PageWebsite",
            '401': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def list_websites_without_preload_content(
        self,
        google_access_token: Annotated[StrictStr, Field(description="The Google access token, must have access to the Google Search Console scope")],
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of results")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List

        List the Websites

        :param google_access_token: The Google access token, must have access to the Google Search Console scope (required)
        :type google_access_token: str
        :param limit: The maximum number of results
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_websites_serialize(
            google_access_token=google_access_token,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PageWebsite",
            '401': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_websites_serialize(
        self,
        google_access_token,
        limit,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if google_access_token is not None:
            
            _query_params.append(('google_access_token', google_access_token))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/ext/google/searchconsole/websites',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

# flake8: noqa
"""
    WordLift Fact-Checking API

    API for semi-automated fact-checking. Returns schema.org/ClaimReview markup. This markup is structured data that contains information about the fact check -- for example, what was the claim being assessed, who made the claim, what was the verdict.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from wordlift_client.models.account import Account
from wordlift_client.models.account_info import AccountInfo
from wordlift_client.models.account_subscription import AccountSubscription
from wordlift_client.models.active_account import ActiveAccount
from wordlift_client.models.add_on_configuration import AddOnConfiguration
from wordlift_client.models.analyses_request import AnalysesRequest
from wordlift_client.models.analyses_response import AnalysesResponse
from wordlift_client.models.analyses_response_item import AnalysesResponseItem
from wordlift_client.models.analytics_import_request import AnalyticsImportRequest
from wordlift_client.models.annotation import Annotation
from wordlift_client.models.autocomplete_result import AutocompleteResult
from wordlift_client.models.batch_request import BatchRequest
from wordlift_client.models.botify_crawl_import_request import BotifyCrawlImportRequest
from wordlift_client.models.build_authorize_uri_request import BuildAuthorizeUriRequest
from wordlift_client.models.build_authorize_uri_response import BuildAuthorizeUriResponse
from wordlift_client.models.classification_request import ClassificationRequest
from wordlift_client.models.classification_response import ClassificationResponse
from wordlift_client.models.completion_request import CompletionRequest
from wordlift_client.models.content_expansion_request import ContentExpansionRequest
from wordlift_client.models.content_expansion_response import ContentExpansionResponse
from wordlift_client.models.content_generation import ContentGeneration
from wordlift_client.models.content_generation_request import ContentGenerationRequest
from wordlift_client.models.content_generation_stats import ContentGenerationStats
from wordlift_client.models.create_embeddings_input import CreateEmbeddingsInput
from wordlift_client.models.create_seo_score200_response import CreateSEOScore200Response
from wordlift_client.models.create_seo_score_request import CreateSEOScoreRequest
from wordlift_client.models.diagnostic_plugin import DiagnosticPlugin
from wordlift_client.models.diagnostic_plugin_request import DiagnosticPluginRequest
from wordlift_client.models.domain_validation_request import DomainValidationRequest
from wordlift_client.models.embedding_request import EmbeddingRequest
from wordlift_client.models.entity import Entity
from wordlift_client.models.entity1 import Entity1
from wordlift_client.models.entity_gap_request import EntityGapRequest
from wordlift_client.models.entity_match import EntityMatch
from wordlift_client.models.entity_patch_request import EntityPatchRequest
from wordlift_client.models.event import Event
from wordlift_client.models.exchange_auth_code_request import ExchangeAuthCodeRequest
from wordlift_client.models.exchange_auth_code_response import ExchangeAuthCodeResponse
from wordlift_client.models.filter import Filter
from wordlift_client.models.filter_value import FilterValue
from wordlift_client.models.generate_sitemap200_response import GenerateSitemap200Response
from wordlift_client.models.generate_sitemap_request import GenerateSitemapRequest
from wordlift_client.models.graphql_request import GraphqlRequest
from wordlift_client.models.html import Html
from wordlift_client.models.image import Image
from wordlift_client.models.include_exclude import IncludeExclude
from wordlift_client.models.include_exclude_request import IncludeExcludeRequest
from wordlift_client.models.inspect_response import InspectResponse
from wordlift_client.models.level_enum import LevelEnum
from wordlift_client.models.longtail_response import LongtailResponse
from wordlift_client.models.merchant import Merchant
from wordlift_client.models.merchant_entry import MerchantEntry
from wordlift_client.models.merchant_request import MerchantRequest
from wordlift_client.models.merchant_sync import MerchantSync
from wordlift_client.models.merchant_view import MerchantView
from wordlift_client.models.model import Model
from wordlift_client.models.model_field import ModelField
from wordlift_client.models.network_account_info import NetworkAccountInfo
from wordlift_client.models.node_request import NodeRequest
from wordlift_client.models.o_auth2_authorized_client import OAuth2AuthorizedClient
from wordlift_client.models.o_auth2_authorized_client_request import OAuth2AuthorizedClientRequest
from wordlift_client.models.page_active_account import PageActiveAccount
from wordlift_client.models.page_add_on_configuration import PageAddOnConfiguration
from wordlift_client.models.page_content_generation import PageContentGeneration
from wordlift_client.models.page_field import PageField
from wordlift_client.models.page_merchant_entry import PageMerchantEntry
from wordlift_client.models.page_merchant_sync import PageMerchantSync
from wordlift_client.models.page_merchant_view import PageMerchantView
from wordlift_client.models.page_model import PageModel
from wordlift_client.models.page_o_auth2_authorized_client import PageOAuth2AuthorizedClient
from wordlift_client.models.page_platform_limit import PagePlatformLimit
from wordlift_client.models.page_preset import PagePreset
from wordlift_client.models.page_record import PageRecord
from wordlift_client.models.page_rule import PageRule
from wordlift_client.models.page_vector_search_query_response_item import PageVectorSearchQueryResponseItem
from wordlift_client.models.page_vector_search_question_response_item import PageVectorSearchQuestionResponseItem
from wordlift_client.models.page_website import PageWebsite
from wordlift_client.models.page_website_search import PageWebsiteSearch
from wordlift_client.models.page_with_limits import PageWithLimits
from wordlift_client.models.page_word import PageWord
from wordlift_client.models.platform_limit import PlatformLimit
from wordlift_client.models.platform_limit_request import PlatformLimitRequest
from wordlift_client.models.preset import Preset
from wordlift_client.models.problem_detail import ProblemDetail
from wordlift_client.models.project_type import ProjectType
from wordlift_client.models.properties import Properties
from wordlift_client.models.properties1 import Properties1
from wordlift_client.models.question_and_answer import QuestionAndAnswer
from wordlift_client.models.question_and_answer_request import QuestionAndAnswerRequest
from wordlift_client.models.rank_entities import RankEntities
from wordlift_client.models.record import Record
from wordlift_client.models.render_request import RenderRequest
from wordlift_client.models.request import Request
from wordlift_client.models.request1 import Request1
from wordlift_client.models.request2 import Request2
from wordlift_client.models.request3 import Request3
from wordlift_client.models.response import Response
from wordlift_client.models.response1 import Response1
from wordlift_client.models.response2 import Response2
from wordlift_client.models.rule import Rule
from wordlift_client.models.rule_request import RuleRequest
from wordlift_client.models.scope import Scope
from wordlift_client.models.sitemap_import_request import SitemapImportRequest
from wordlift_client.models.smart_content import SmartContent
from wordlift_client.models.smart_content_request import SmartContentRequest
from wordlift_client.models.submit_fact_check200_response import SubmitFactCheck200Response
from wordlift_client.models.submit_fact_check_request import SubmitFactCheckRequest
from wordlift_client.models.topic import Topic
from wordlift_client.models.update_account_request import UpdateAccountRequest
from wordlift_client.models.update_question_and_answer_request import UpdateQuestionAndAnswerRequest
from wordlift_client.models.update_record_request import UpdateRecordRequest
from wordlift_client.models.update_records_request import UpdateRecordsRequest
from wordlift_client.models.validation_fix import ValidationFix
from wordlift_client.models.validation_result import ValidationResult
from wordlift_client.models.validation_type_enum import ValidationTypeEnum
from wordlift_client.models.vector_search_query_request import VectorSearchQueryRequest
from wordlift_client.models.vector_search_query_response_item import VectorSearchQueryResponseItem
from wordlift_client.models.vector_search_question_request import VectorSearchQuestionRequest
from wordlift_client.models.vector_search_question_response_item import VectorSearchQuestionResponseItem
from wordlift_client.models.web_async import WebAsync
from wordlift_client.models.web_page import WebPage
from wordlift_client.models.webpage_properties import WebpageProperties
from wordlift_client.models.website import Website
from wordlift_client.models.website_search import WebsiteSearch
from wordlift_client.models.what_operand_lhs import WhatOperandLhs
from wordlift_client.models.what_operator import WhatOperator
from wordlift_client.models.when_operator import WhenOperator
from wordlift_client.models.with_limits import WithLimits
from wordlift_client.models.word import Word
from wordlift_client.models.word_repetition_data import WordRepetitionData
from wordlift_client.models.word_request import WordRequest



# coding: utf-8

"""
    WordLift Fact-Checking API

    API for semi-automated fact-checking. Returns schema.org/ClaimReview markup. This markup is structured data that contains information about the fact check -- for example, what was the claim being assessed, who made the claim, what was the verdict.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from wordlift_client.models.merchant import Merchant
from wordlift_client.models.merchant_request import MerchantRequest
from wordlift_client.models.page_merchant_view import PageMerchantView

from wordlift_client.api_client import ApiClient, RequestSerialized
from wordlift_client.api_response import ApiResponse
from wordlift_client.rest import RESTResponseType


class MerchantsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    async def create_merchant(
        self,
        merchant_request: MerchantRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Merchant:
        """Create

        Create a Merchant

        :param merchant_request: (required)
        :type merchant_request: MerchantRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_merchant_serialize(
            merchant_request=merchant_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Merchant",
            '401': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def create_merchant_with_http_info(
        self,
        merchant_request: MerchantRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Merchant]:
        """Create

        Create a Merchant

        :param merchant_request: (required)
        :type merchant_request: MerchantRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_merchant_serialize(
            merchant_request=merchant_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Merchant",
            '401': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def create_merchant_without_preload_content(
        self,
        merchant_request: MerchantRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create

        Create a Merchant

        :param merchant_request: (required)
        :type merchant_request: MerchantRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_merchant_serialize(
            merchant_request=merchant_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Merchant",
            '401': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_merchant_serialize(
        self,
        merchant_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if merchant_request is not None:
            _body_params = merchant_request


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/merchants',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def delete_merchant(
        self,
        id: Annotated[StrictInt, Field(description="The Merchant id")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Delete by id

        Delete a Merchant by its `id`.

        :param id: The Merchant id (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_merchant_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '401': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def delete_merchant_with_http_info(
        self,
        id: Annotated[StrictInt, Field(description="The Merchant id")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Delete by id

        Delete a Merchant by its `id`.

        :param id: The Merchant id (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_merchant_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '401': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def delete_merchant_without_preload_content(
        self,
        id: Annotated[StrictInt, Field(description="The Merchant id")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete by id

        Delete a Merchant by its `id`.

        :param id: The Merchant id (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_merchant_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '401': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_merchant_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/merchants/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def get_merchant(
        self,
        id: Annotated[StrictInt, Field(description="The Merchant id")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Merchant:
        """Get by id

        Get a Merchant by its `id`.

        :param id: The Merchant id (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_merchant_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Merchant",
            '401': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def get_merchant_with_http_info(
        self,
        id: Annotated[StrictInt, Field(description="The Merchant id")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Merchant]:
        """Get by id

        Get a Merchant by its `id`.

        :param id: The Merchant id (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_merchant_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Merchant",
            '401': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def get_merchant_without_preload_content(
        self,
        id: Annotated[StrictInt, Field(description="The Merchant id")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get by id

        Get a Merchant by its `id`.

        :param id: The Merchant id (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_merchant_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Merchant",
            '401': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_merchant_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/merchants/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def list_merchants(
        self,
        cursor: Annotated[Optional[StrictStr], Field(description="The cursor")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of results")] = None,
        deleted: Annotated[Optional[StrictBool], Field(description="Filter by the `deleted` flag")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PageMerchantView:
        """List

        List the Merchants, optionally filtering by the `deleted` flag

        :param cursor: The cursor
        :type cursor: str
        :param limit: The maximum number of results
        :type limit: int
        :param deleted: Filter by the `deleted` flag
        :type deleted: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_merchants_serialize(
            cursor=cursor,
            limit=limit,
            deleted=deleted,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PageMerchantView",
            '401': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def list_merchants_with_http_info(
        self,
        cursor: Annotated[Optional[StrictStr], Field(description="The cursor")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of results")] = None,
        deleted: Annotated[Optional[StrictBool], Field(description="Filter by the `deleted` flag")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PageMerchantView]:
        """List

        List the Merchants, optionally filtering by the `deleted` flag

        :param cursor: The cursor
        :type cursor: str
        :param limit: The maximum number of results
        :type limit: int
        :param deleted: Filter by the `deleted` flag
        :type deleted: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_merchants_serialize(
            cursor=cursor,
            limit=limit,
            deleted=deleted,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PageMerchantView",
            '401': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def list_merchants_without_preload_content(
        self,
        cursor: Annotated[Optional[StrictStr], Field(description="The cursor")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of results")] = None,
        deleted: Annotated[Optional[StrictBool], Field(description="Filter by the `deleted` flag")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List

        List the Merchants, optionally filtering by the `deleted` flag

        :param cursor: The cursor
        :type cursor: str
        :param limit: The maximum number of results
        :type limit: int
        :param deleted: Filter by the `deleted` flag
        :type deleted: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_merchants_serialize(
            cursor=cursor,
            limit=limit,
            deleted=deleted,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PageMerchantView",
            '401': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_merchants_serialize(
        self,
        cursor,
        limit,
        deleted,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if cursor is not None:
            
            _query_params.append(('cursor', cursor))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if deleted is not None:
            
            _query_params.append(('deleted', deleted))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/merchants',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def update_merchant(
        self,
        id: Annotated[StrictInt, Field(description="The Merchant id")],
        merchant_request: MerchantRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Merchant:
        """Update

        Update a Merchant

        :param id: The Merchant id (required)
        :type id: int
        :param merchant_request: (required)
        :type merchant_request: MerchantRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_merchant_serialize(
            id=id,
            merchant_request=merchant_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Merchant",
            '401': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def update_merchant_with_http_info(
        self,
        id: Annotated[StrictInt, Field(description="The Merchant id")],
        merchant_request: MerchantRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Merchant]:
        """Update

        Update a Merchant

        :param id: The Merchant id (required)
        :type id: int
        :param merchant_request: (required)
        :type merchant_request: MerchantRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_merchant_serialize(
            id=id,
            merchant_request=merchant_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Merchant",
            '401': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def update_merchant_without_preload_content(
        self,
        id: Annotated[StrictInt, Field(description="The Merchant id")],
        merchant_request: MerchantRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update

        Update a Merchant

        :param id: The Merchant id (required)
        :type id: int
        :param merchant_request: (required)
        :type merchant_request: MerchantRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_merchant_serialize(
            id=id,
            merchant_request=merchant_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Merchant",
            '401': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_merchant_serialize(
        self,
        id,
        merchant_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if merchant_request is not None:
            _body_params = merchant_request


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/merchants/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.google_search_console_o_auth2_api import GoogleSearchConsoleOAuth2Api


class TestGoogleSearchConsoleOAuth2Api(unittest.TestCase):
    """GoogleSearchConsoleOAuth2Api unit test stubs"""

    def setUp(self) -> None:
        self.api = GoogleSearchConsoleOAuth2Api()

    def tearDown(self) -> None:
        pass

    def test_create_auth_code_exchange(self) -> None:
        """Test case for create_auth_code_exchange

        Get an Access Code
        """
        pass

    def test_create_authorize_uri(self) -> None:
        """Test case for create_authorize_uri

        Create an Authorization URI
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    WordLift Fact-Checking API

    API for semi-automated fact-checking. Returns schema.org/ClaimReview markup. This markup is structured data that contains information about the fact check -- for example, what was the claim being assessed, who made the claim, what was the verdict.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class ContentGenerationRequest(BaseModel):
    """
    The Content Generation request.
    """ # noqa: E501
    account_id: StrictInt = Field(description="The account id bound to this content generation.")
    deleted: Optional[StrictBool] = Field(default=False, description="The deleted flag.")
    graphql_query: StrictStr = Field(description="The GraphQL query which will be used to import entity data from the Knowledge Graph.")
    max_tokens: Optional[Annotated[int, Field(le=2000, strict=True, ge=0)]] = Field(default=64, description="The maximum number of tokens.")
    min_words: Optional[StrictInt] = Field(default=0, description="Minimum amount of words per completion.")
    model_id: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=1, description="The model ID.")
    name: Annotated[str, Field(min_length=0, strict=True, max_length=250)] = Field(description="The model name.")
    penalty: Optional[Union[Annotated[float, Field(le=1.9, strict=True, ge=0.5)], Annotated[int, Field(le=1, strict=True, ge=1)]]] = Field(default=0.5, description="The penalty score.")
    prompt_template: Optional[StrictStr] = Field(default=None, description="The prompt template.")
    stop: Optional[StrictStr] = Field(default='###', description="The stop sequence.")
    temperature: Optional[Union[Annotated[float, Field(le=0.8, strict=True, ge=0.4)], Annotated[int, Field(le=0, strict=True, ge=1)]]] = Field(default=0.4, description="The temperature score.")
    words_to_ignore: Optional[List[StrictStr]] = Field(default=None, description="Words to ignore when checking for words not in prompt.")
    __properties: ClassVar[List[str]] = ["account_id", "deleted", "graphql_query", "max_tokens", "min_words", "model_id", "name", "penalty", "prompt_template", "stop", "temperature", "words_to_ignore"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ContentGenerationRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ContentGenerationRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "account_id": obj.get("account_id"),
            "deleted": obj.get("deleted") if obj.get("deleted") is not None else False,
            "graphql_query": obj.get("graphql_query"),
            "max_tokens": obj.get("max_tokens") if obj.get("max_tokens") is not None else 64,
            "min_words": obj.get("min_words") if obj.get("min_words") is not None else 0,
            "model_id": obj.get("model_id") if obj.get("model_id") is not None else 1,
            "name": obj.get("name"),
            "penalty": obj.get("penalty") if obj.get("penalty") is not None else 0.5,
            "prompt_template": obj.get("prompt_template"),
            "stop": obj.get("stop") if obj.get("stop") is not None else '###',
            "temperature": obj.get("temperature") if obj.get("temperature") is not None else 0.4,
            "words_to_ignore": obj.get("words_to_ignore")
        })
        return _obj





# coding: utf-8

"""
    WordLift Fact-Checking API

    API for semi-automated fact-checking. Returns schema.org/ClaimReview markup. This markup is structured data that contains information about the fact check -- for example, what was the claim being assessed, who made the claim, what was the verdict.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class AnalysesRequest(BaseModel):
    """
    The analysis request.
    """ # noqa: E501
    text: Optional[StrictStr] = Field(default=None, description="The text to analyse.")
    url: Optional[StrictStr] = Field(default=None, description="The URL to analyse.")
    query: Optional[StrictStr] = Field(default=None, description="The query string to analyse.")
    html: Optional[StrictStr] = Field(default=None, description="The html to analyse.")
    language_code: Optional[StrictStr] = Field(default='en', description="The language code used for content analysis, e.g. `en`.")
    query_location_name: Optional[StrictStr] = Field(default='United States', description="The location name for the query, e.g. United Kingdom.")
    query_search_engine: Optional[StrictStr] = Field(default=None, description="The search engine domain for the query, if not set will be chosen according to `query_location_name`")
    linked_data: Optional[StrictBool] = Field(default=True, description="Whether to include results from Linked Data (e.g. DBpedia), by default true.")
    local_data: Optional[StrictBool] = Field(default=True, description="Whether to include results from the local Knowledge Graph, by default true.")
    network_data: Optional[StrictBool] = Field(default=True, description="Whether to include results from connected Knowledge Graphs, by default true.")
    __properties: ClassVar[List[str]] = ["text", "url", "query", "html", "language_code", "query_location_name", "query_search_engine", "linked_data", "local_data", "network_data"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AnalysesRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AnalysesRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "text": obj.get("text"),
            "url": obj.get("url"),
            "query": obj.get("query"),
            "html": obj.get("html"),
            "language_code": obj.get("language_code") if obj.get("language_code") is not None else 'en',
            "query_location_name": obj.get("query_location_name") if obj.get("query_location_name") is not None else 'United States',
            "query_search_engine": obj.get("query_search_engine"),
            "linked_data": obj.get("linked_data") if obj.get("linked_data") is not None else True,
            "local_data": obj.get("local_data") if obj.get("local_data") is not None else True,
            "network_data": obj.get("network_data") if obj.get("network_data") is not None else True
        })
        return _obj





# coding: utf-8

"""
    WordLift Fact-Checking API

    API for semi-automated fact-checking. Returns schema.org/ClaimReview markup. This markup is structured data that contains information about the fact check -- for example, what was the claim being assessed, who made the claim, what was the verdict.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from wordlift_client.models.validation_result import ValidationResult
from typing import Optional, Set
from typing_extensions import Self

class QuestionAndAnswer(BaseModel):
    """
    Generated Q&A content.
    """ # noqa: E501
    answer: Optional[StrictStr] = Field(default=None, description="The generated answer.")
    created_at: Optional[datetime] = Field(default=None, description="The create date-time.")
    entity_gaps: Optional[List[StrictStr]] = None
    errors: Optional[List[ValidationResult]] = Field(default=None, description="The set of errors found for the answer.")
    id: Optional[StrictInt] = Field(default=None, description="The unique id.")
    iri: StrictStr = Field(description="The webpage IRI tied to this Q&A.")
    is_deleted: Optional[StrictBool] = Field(default=False, description="The deleted flag.")
    is_published: Optional[StrictBool] = Field(default=False, description="The published flag.")
    modified_at: Optional[datetime] = Field(default=None, description="The last modified date-time.")
    question: Optional[StrictStr] = Field(default=None, description="The generated question.")
    smart_content_id: Optional[StrictInt] = None
    url: StrictStr = Field(description="The webpage URL tied to this Q&A.")
    warnings: Optional[List[ValidationResult]] = Field(default=None, description="The set of warnings found for the answer.")
    __properties: ClassVar[List[str]] = ["answer", "created_at", "entity_gaps", "errors", "id", "iri", "is_deleted", "is_published", "modified_at", "question", "smart_content_id", "url", "warnings"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of QuestionAndAnswer from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "created_at",
            "errors",
            "id",
            "modified_at",
            "warnings",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in errors (list)
        _items = []
        if self.errors:
            for _item in self.errors:
                if _item:
                    _items.append(_item.to_dict())
            _dict['errors'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in warnings (list)
        _items = []
        if self.warnings:
            for _item in self.warnings:
                if _item:
                    _items.append(_item.to_dict())
            _dict['warnings'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of QuestionAndAnswer from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "answer": obj.get("answer"),
            "created_at": obj.get("created_at"),
            "entity_gaps": obj.get("entity_gaps"),
            "errors": [ValidationResult.from_dict(_item) for _item in obj["errors"]] if obj.get("errors") is not None else None,
            "id": obj.get("id"),
            "iri": obj.get("iri"),
            "is_deleted": obj.get("is_deleted") if obj.get("is_deleted") is not None else False,
            "is_published": obj.get("is_published") if obj.get("is_published") is not None else False,
            "modified_at": obj.get("modified_at"),
            "question": obj.get("question"),
            "smart_content_id": obj.get("smart_content_id"),
            "url": obj.get("url"),
            "warnings": [ValidationResult.from_dict(_item) for _item in obj["warnings"]] if obj.get("warnings") is not None else None
        })
        return _obj





# coding: utf-8

"""
    WordLift Fact-Checking API

    API for semi-automated fact-checking. Returns schema.org/ClaimReview markup. This markup is structured data that contains information about the fact check -- for example, what was the claim being assessed, who made the claim, what was the verdict.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ValidationTypeEnum(str, Enum):
    """
    ValidationTypeEnum
    """

    """
    allowed enum values
    """
    FIND_AND_REPLACE = 'FIND_AND_REPLACE'
    OPEN_AI = 'OPEN_AI'
    APPEND = 'APPEND'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ValidationTypeEnum from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    WordLift Fact-Checking API

    API for semi-automated fact-checking. Returns schema.org/ClaimReview markup. This markup is structured data that contains information about the fact check -- for example, what was the claim being assessed, who made the claim, what was the verdict.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class SmartContent(BaseModel):
    """
    A Smart Content project.
    """ # noqa: E501
    account_id: StrictInt = Field(description="The account id.")
    created_at: Optional[datetime] = Field(default=None, description="The create date-time.")
    id: Optional[StrictInt] = Field(default=None, description="The unique id.")
    model_id: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=1, description="The model id.")
    __properties: ClassVar[List[str]] = ["account_id", "created_at", "id", "model_id"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SmartContent from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "account_id",
            "created_at",
            "id",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SmartContent from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "account_id": obj.get("account_id"),
            "created_at": obj.get("created_at"),
            "id": obj.get("id"),
            "model_id": obj.get("model_id") if obj.get("model_id") is not None else 1
        })
        return _obj





# flake8: noqa

# import apis into api package
from wordlift_client.api.account_api import AccountApi
from wordlift_client.api.accounts_api import AccountsApi
from wordlift_client.api.add_ons_api import AddOnsApi
from wordlift_client.api.analyses_api import AnalysesApi
from wordlift_client.api.analytics_imports_api import AnalyticsImportsApi
from wordlift_client.api.autocomplete_api import AutocompleteApi
from wordlift_client.api.botify_crawl_imports_api import BotifyCrawlImportsApi
from wordlift_client.api.classifications_api import ClassificationsApi
from wordlift_client.api.content_expansions_api import ContentExpansionsApi
from wordlift_client.api.content_generation_completion_api import ContentGenerationCompletionApi
from wordlift_client.api.content_generation_fields_api import ContentGenerationFieldsApi
from wordlift_client.api.content_generation_models_api import ContentGenerationModelsApi
from wordlift_client.api.content_generation_presets_api import ContentGenerationPresetsApi
from wordlift_client.api.content_generation_records_api import ContentGenerationRecordsApi
from wordlift_client.api.content_generation_records_export_api import ContentGenerationRecordsExportApi
from wordlift_client.api.content_generation_renders_api import ContentGenerationRendersApi
from wordlift_client.api.content_generation_stats_api import ContentGenerationStatsApi
from wordlift_client.api.content_generation_syncs_api import ContentGenerationSyncsApi
from wordlift_client.api.content_generation_word_biases_api import ContentGenerationWordBiasesApi
from wordlift_client.api.content_generations_api import ContentGenerationsApi
from wordlift_client.api.custom_domains_api import CustomDomainsApi
from wordlift_client.api.data_uri_api import DataURIApi
from wordlift_client.api.dataset_api import DatasetApi
from wordlift_client.api.embedding_api import EmbeddingApi
from wordlift_client.api.embeddings_api import EmbeddingsApi
from wordlift_client.api.entities_api import EntitiesApi
from wordlift_client.api.entity_gaps_api import EntityGapsApi
from wordlift_client.api.fact_check_api import FactCheckApi
from wordlift_client.api.google_merchants_api import GoogleMerchantsApi
from wordlift_client.api.google_search_console_api import GoogleSearchConsoleApi
from wordlift_client.api.google_search_console_o_auth2_api import GoogleSearchConsoleOAuth2Api
from wordlift_client.api.google_search_console_searches_api import GoogleSearchConsoleSearchesApi
from wordlift_client.api.graph_ql_api import GraphQLApi
from wordlift_client.api.include_excludes_word_press_plugin_api import IncludeExcludesWordPressPluginApi
from wordlift_client.api.inspector_api import InspectorApi
from wordlift_client.api.long_tails_api import LongTailsApi
from wordlift_client.api.merchant_syncs_api import MerchantSyncsApi
from wordlift_client.api.merchants_api import MerchantsApi
from wordlift_client.api.microdata_api import MicrodataApi
from wordlift_client.api.o_auth2_authorized_clients_api import OAuth2AuthorizedClientsApi
from wordlift_client.api.platform_consumptions_api import PlatformConsumptionsApi
from wordlift_client.api.platform_limits_api import PlatformLimitsApi
from wordlift_client.api.plugin_diagnostics_api import PluginDiagnosticsApi
from wordlift_client.api.plugin_events_api import PluginEventsApi
from wordlift_client.api.questions_and_answers_api import QuestionsAndAnswersApi
from wordlift_client.api.redeem_codes_api import RedeemCodesApi
from wordlift_client.api.rules_api import RulesApi
from wordlift_client.api.seo_scores_api import SEOScoresApi
from wordlift_client.api.sitemap_generator_api import SitemapGeneratorApi
from wordlift_client.api.sitemap_imports_api import SitemapImportsApi
from wordlift_client.api.summarizations_api import SummarizationsApi
from wordlift_client.api.vector_search_nodes_api import VectorSearchNodesApi
from wordlift_client.api.vector_search_queries_api import VectorSearchQueriesApi
from wordlift_client.api.vector_search_questions_api import VectorSearchQuestionsApi
from wordlift_client.api.web_asyncs_metadata_api import WebAsyncsMetadataApi
from wordlift_client.api.web_asyncs_responses_api import WebAsyncsResponsesApi




# coding: utf-8

"""
    WordLift Fact-Checking API

    API for semi-automated fact-checking. Returns schema.org/ClaimReview markup. This markup is structured data that contains information about the fact check -- for example, what was the claim being assessed, who made the claim, what was the verdict.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from wordlift_client.models.validation_result import ValidationResult
from wordlift_client.models.word_repetition_data import WordRepetitionData
from typing import Optional, Set
from typing_extensions import Self

class Record(BaseModel):
    """
    Record
    """ # noqa: E501
    completion: Optional[StrictStr] = None
    content_generation_id: StrictInt = Field(description="The parent content generation id.")
    data: Optional[Dict[str, Any]] = Field(default=None, description="The data from knowledge graph after applying the graphql query.")
    errors: Optional[List[ValidationResult]] = Field(default=None, description="The set of errors found for record.")
    has_upvote: StrictBool = Field(description="This indicates whether the user upvoted the completion.")
    id: Optional[StrictInt] = None
    is_accepted: StrictBool = Field(description="This indicates whether the completion is accepted by the user.")
    modified_at: Optional[datetime] = Field(default=None, description="The last modified date-time.")
    not_in_prompt_words: Optional[List[StrictStr]] = Field(default=None, description="Words in completion that are not in the prompt.")
    prompt: StrictStr = Field(description="The prompt.")
    repeated_words: Optional[Dict[str, WordRepetitionData]] = Field(default=None, description="Words in completion which are repeated.")
    status: Optional[StrictStr] = Field(default=None, description="The status of the record, whether it's accepted, with errors, with warnings or valid.")
    validated_at: Optional[datetime] = Field(default=None, description="The last validation date-time.")
    warnings: Optional[List[ValidationResult]] = Field(default=None, description="The set of errors found for record.")
    __properties: ClassVar[List[str]] = ["completion", "content_generation_id", "data", "errors", "has_upvote", "id", "is_accepted", "modified_at", "not_in_prompt_words", "prompt", "repeated_words", "status", "validated_at", "warnings"]

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['accepted', 'warnings', 'errors', 'valid']):
            raise ValueError("must be one of enum values ('accepted', 'warnings', 'errors', 'valid')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Record from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "content_generation_id",
            "data",
            "errors",
            "modified_at",
            "not_in_prompt_words",
            "repeated_words",
            "status",
            "validated_at",
            "warnings",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in errors (list)
        _items = []
        if self.errors:
            for _item in self.errors:
                if _item:
                    _items.append(_item.to_dict())
            _dict['errors'] = _items
        # override the default output from pydantic by calling `to_dict()` of each value in repeated_words (dict)
        _field_dict = {}
        if self.repeated_words:
            for _key in self.repeated_words:
                if self.repeated_words[_key]:
                    _field_dict[_key] = self.repeated_words[_key].to_dict()
            _dict['repeated_words'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each item in warnings (list)
        _items = []
        if self.warnings:
            for _item in self.warnings:
                if _item:
                    _items.append(_item.to_dict())
            _dict['warnings'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Record from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "completion": obj.get("completion"),
            "content_generation_id": obj.get("content_generation_id"),
            "data": obj.get("data"),
            "errors": [ValidationResult.from_dict(_item) for _item in obj["errors"]] if obj.get("errors") is not None else None,
            "has_upvote": obj.get("has_upvote"),
            "id": obj.get("id"),
            "is_accepted": obj.get("is_accepted"),
            "modified_at": obj.get("modified_at"),
            "not_in_prompt_words": obj.get("not_in_prompt_words"),
            "prompt": obj.get("prompt"),
            "repeated_words": dict(
                (_k, WordRepetitionData.from_dict(_v))
                for _k, _v in obj["repeated_words"].items()
            )
            if obj.get("repeated_words") is not None
            else None,
            "status": obj.get("status"),
            "validated_at": obj.get("validated_at"),
            "warnings": [ValidationResult.from_dict(_item) for _item in obj["warnings"]] if obj.get("warnings") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.record import Record

class TestRecord(unittest.TestCase):
    """Record unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Record:
        """Test Record
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Record`
        """
        model = Record()
        if include_optional:
            return Record(
                completion = '',
                content_generation_id = 56,
                data = wordlift_client.models.json.Json(),
                errors = [
                    wordlift_client.models.validation_result.ValidationResult(
                        level_enum = 'RECOMMENDED', 
                        name = '', 
                        result = 'PASS', )
                    ],
                has_upvote = True,
                id = 56,
                is_accepted = True,
                modified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                not_in_prompt_words = [
                    ''
                    ],
                prompt = '',
                repeated_words = {
                    'key' : wordlift_client.models.word_repetition_data.WordRepetitionData(
                        count = 56, 
                        repeated_in_same_sentence = True, )
                    },
                status = 'accepted',
                validated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                warnings = [
                    wordlift_client.models.validation_result.ValidationResult(
                        level_enum = 'RECOMMENDED', 
                        name = '', 
                        result = 'PASS', )
                    ]
            )
        else:
            return Record(
                content_generation_id = 56,
                has_upvote = True,
                is_accepted = True,
                prompt = '',
        )
        """

    def testRecord(self):
        """Test Record"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.vector_search_nodes_api import VectorSearchNodesApi


class TestVectorSearchNodesApi(unittest.TestCase):
    """VectorSearchNodesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = VectorSearchNodesApi()

    def tearDown(self) -> None:
        pass

    def test_update_nodes_collection(self) -> None:
        """Test case for update_nodes_collection

        Update
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    WordLift Fact-Checking API

    API for semi-automated fact-checking. Returns schema.org/ClaimReview markup. This markup is structured data that contains information about the fact check -- for example, what was the claim being assessed, who made the claim, what was the verdict.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class Merchant(BaseModel):
    """
    A Merchant project.
    """ # noqa: E501
    access_token: StrictStr = Field(description="The Google merchant access token")
    account_id: Optional[StrictInt] = Field(default=None, description="The account id")
    automatic_synchronization: Optional[StrictBool] = Field(default=None, description="Whether the Merchant data will be synchronized automatically")
    created_at: Optional[datetime] = Field(default=None, description="The create date-time")
    dataset_domain: Optional[StrictStr] = Field(default=None, description="The custom domain (for example data.example.org)")
    dataset_name: Optional[StrictStr] = Field(default=None, description="The dataset path (for example /data)")
    deleted: StrictBool = Field(description="True if the merchant has been deleted")
    deleted_at: Optional[datetime] = Field(default=None, description="The delete date-time")
    google_merchant_id: StrictInt = Field(description="The Google Merchant id")
    id: Optional[StrictInt] = Field(default=None, description="The unique id")
    ignore_brand: Optional[StrictBool] = Field(default=None, description="Whether to ignore the `brand` property during validation")
    ignore_image: Optional[StrictBool] = Field(default=None, description="Whether to ignore the `image` property during validation")
    modified_at: Optional[datetime] = Field(default=None, description="The last modified date-time")
    publisher_name: StrictStr = Field(description="The publisher name (shows in schema publisher)")
    refresh_token: StrictStr = Field(description="The Google merchant refresh token")
    url: Optional[StrictStr] = Field(default=None, description="The website URL")
    writer_service: Optional[StrictStr] = Field(default=None, description="How to write the merchant data to the graph, if unsure, do not set anything (by default `wordpressMerchantWriter`).")
    __properties: ClassVar[List[str]] = ["access_token", "account_id", "automatic_synchronization", "created_at", "dataset_domain", "dataset_name", "deleted", "deleted_at", "google_merchant_id", "id", "ignore_brand", "ignore_image", "modified_at", "publisher_name", "refresh_token", "url", "writer_service"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Merchant from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "account_id",
            "created_at",
            "deleted_at",
            "id",
            "modified_at",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Merchant from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "access_token": obj.get("access_token"),
            "account_id": obj.get("account_id"),
            "automatic_synchronization": obj.get("automatic_synchronization"),
            "created_at": obj.get("created_at"),
            "dataset_domain": obj.get("dataset_domain"),
            "dataset_name": obj.get("dataset_name"),
            "deleted": obj.get("deleted") if obj.get("deleted") is not None else False,
            "deleted_at": obj.get("deleted_at"),
            "google_merchant_id": obj.get("google_merchant_id"),
            "id": obj.get("id"),
            "ignore_brand": obj.get("ignore_brand"),
            "ignore_image": obj.get("ignore_image"),
            "modified_at": obj.get("modified_at"),
            "publisher_name": obj.get("publisher_name"),
            "refresh_token": obj.get("refresh_token"),
            "url": obj.get("url"),
            "writer_service": obj.get("writer_service")
        })
        return _obj





# coding: utf-8

"""
    WordLift Fact-Checking API

    API for semi-automated fact-checking. Returns schema.org/ClaimReview markup. This markup is structured data that contains information about the fact check -- for example, what was the claim being assessed, who made the claim, what was the verdict.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class Account(BaseModel):
    """
    Account
    """ # noqa: E501
    analytics_client_factory: Optional[StrictStr] = None
    analyzer_id: Optional[StrictInt] = Field(default=None, alias="analyzerId")
    botify_project: Optional[StrictStr] = None
    botify_token: Optional[StrictStr] = None
    botify_username: Optional[StrictStr] = None
    collection: Optional[StrictStr] = Field(default='entity', description="The collection hosing the Knowledge Graph.")
    country: Optional[StrictStr] = None
    dataset_id: Optional[StrictStr] = Field(default=None, alias="datasetId")
    dataset_uri: Optional[StrictStr] = Field(default=None, alias="datasetUri")
    domain_uri: Optional[StrictStr] = Field(default=None, alias="domainUri")
    google_search_console_site_url: Optional[StrictStr] = None
    id: Optional[StrictInt] = None
    indexed: Optional[StrictBool] = None
    is_wordpress: Optional[StrictBool] = None
    key: Optional[StrictStr] = None
    language: Optional[StrictStr] = None
    ng_dataset_id: Optional[StrictStr] = Field(default=None, alias="ngDatasetId")
    resolved_url: Optional[StrictStr] = Field(default=None, alias="resolvedUrl")
    subscription_id: Optional[StrictInt] = Field(default=None, alias="subscriptionId")
    url: Optional[StrictStr] = None
    wp_admin: Optional[StrictStr] = Field(default=None, alias="wpAdmin")
    wp_json: Optional[StrictStr] = Field(default=None, alias="wpJson")
    wp_include_exclude_default: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["analytics_client_factory", "analyzerId", "botify_project", "botify_token", "botify_username", "collection", "country", "datasetId", "datasetUri", "domainUri", "google_search_console_site_url", "id", "indexed", "is_wordpress", "key", "language", "ngDatasetId", "resolvedUrl", "subscriptionId", "url", "wpAdmin", "wpJson", "wp_include_exclude_default"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Account from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Account from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "analytics_client_factory": obj.get("analytics_client_factory"),
            "analyzerId": obj.get("analyzerId"),
            "botify_project": obj.get("botify_project"),
            "botify_token": obj.get("botify_token"),
            "botify_username": obj.get("botify_username"),
            "collection": obj.get("collection") if obj.get("collection") is not None else 'entity',
            "country": obj.get("country"),
            "datasetId": obj.get("datasetId"),
            "datasetUri": obj.get("datasetUri"),
            "domainUri": obj.get("domainUri"),
            "google_search_console_site_url": obj.get("google_search_console_site_url"),
            "id": obj.get("id"),
            "indexed": obj.get("indexed"),
            "is_wordpress": obj.get("is_wordpress"),
            "key": obj.get("key"),
            "language": obj.get("language"),
            "ngDatasetId": obj.get("ngDatasetId"),
            "resolvedUrl": obj.get("resolvedUrl"),
            "subscriptionId": obj.get("subscriptionId"),
            "url": obj.get("url"),
            "wpAdmin": obj.get("wpAdmin"),
            "wpJson": obj.get("wpJson"),
            "wp_include_exclude_default": obj.get("wp_include_exclude_default")
        })
        return _obj





# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.page_record import PageRecord

class TestPageRecord(unittest.TestCase):
    """PageRecord unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PageRecord:
        """Test PageRecord
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PageRecord`
        """
        model = PageRecord()
        if include_optional:
            return PageRecord(
                first = '',
                items = [
                    wordlift_client.models.record.Record(
                        completion = '', 
                        content_generation_id = 56, 
                        data = wordlift_client.models.json.Json(), 
                        errors = [
                            wordlift_client.models.validation_result.ValidationResult(
                                level_enum = 'RECOMMENDED', 
                                name = '', 
                                result = 'PASS', )
                            ], 
                        has_upvote = True, 
                        id = 56, 
                        is_accepted = True, 
                        modified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        not_in_prompt_words = [
                            ''
                            ], 
                        prompt = '', 
                        repeated_words = {
                            'key' : wordlift_client.models.word_repetition_data.WordRepetitionData(
                                count = 56, 
                                repeated_in_same_sentence = True, )
                            }, 
                        status = 'accepted', 
                        validated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        warnings = [
                            wordlift_client.models.validation_result.ValidationResult(
                                name = '', 
                                result = 'PASS', )
                            ], )
                    ],
                last = '',
                next = '',
                prev = '',
                var_self = ''
            )
        else:
            return PageRecord(
                first = '',
                items = [
                    wordlift_client.models.record.Record(
                        completion = '', 
                        content_generation_id = 56, 
                        data = wordlift_client.models.json.Json(), 
                        errors = [
                            wordlift_client.models.validation_result.ValidationResult(
                                level_enum = 'RECOMMENDED', 
                                name = '', 
                                result = 'PASS', )
                            ], 
                        has_upvote = True, 
                        id = 56, 
                        is_accepted = True, 
                        modified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        not_in_prompt_words = [
                            ''
                            ], 
                        prompt = '', 
                        repeated_words = {
                            'key' : wordlift_client.models.word_repetition_data.WordRepetitionData(
                                count = 56, 
                                repeated_in_same_sentence = True, )
                            }, 
                        status = 'accepted', 
                        validated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        warnings = [
                            wordlift_client.models.validation_result.ValidationResult(
                                name = '', 
                                result = 'PASS', )
                            ], )
                    ],
                last = '',
                next = '',
                prev = '',
                var_self = '',
        )
        """

    def testPageRecord(self):
        """Test PageRecord"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.rank_entities import RankEntities

class TestRankEntities(unittest.TestCase):
    """RankEntities unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RankEntities:
        """Test RankEntities
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RankEntities`
        """
        model = RankEntities()
        if include_optional:
            return RankEntities(
                rank = 56,
                entities = [
                    wordlift_client.models.entity1.Entity1(
                        reference = '', 
                        properties = wordlift_client.models.properties1.Properties1(
                            name = '', 
                            same_as = [
                                ''
                                ], ), )
                    ]
            )
        else:
            return RankEntities(
        )
        """

    def testRankEntities(self):
        """Test RankEntities"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
